@@ -63,10 +63,10 @@ class startControl(QThread):
         endpoint = 'hamlib'
         RIG_PORT = HAMLIB_PORT
         TCP_IP = self.hamlibIPv
-        TCP_IP = '127.0.0.1'
-        HAMLIB_PORT = 9537
-        self.gqrxIPv = '127.0.0.1'
-        GQRX_PORT = 9536
+        #TCP_IP = '127.0.0.1'
+        #HAMLIB_PORT = 4532
+        #self.gqrxIPv = '127.0.0.1'
+        #GQRX_PORT = 7356
         #TCP_IP = "'127.0.0.1'"
         #HAMLIB_PORT = "'9537'"
         #self.gqrxIPv = "'127.0.0.1'"
